var group__arrayfire__func =
[
    [ "DoG", "group__cv__func__dog.htm", "group__cv__func__dog" ],
    [ "Random Number Generation", "group__random__mat.htm", "group__random__mat" ],
    [ "SAT", "group__image__func__sat.htm", "group__image__func__sat" ],
    [ "abs", "group__arith__func__abs.htm", "group__arith__func__abs" ],
    [ "accum", "group__scan__func__accum.htm", "group__scan__func__accum" ],
    [ "acos", "group__arith__func__acos.htm", "group__arith__func__acos" ],
    [ "acosh", "group__arith__func__acosh.htm", "group__arith__func__acosh" ],
    [ "add", "group__arith__func__add.htm", "group__arith__func__add" ],
    [ "alloc", "group__device__func__alloc.htm", "group__device__func__alloc" ],
    [ "allocHost", "group__device__func__alloc__host.htm", "group__device__func__alloc__host" ],
    [ "alltrue", "group__reduce__func__all__true.htm", "group__reduce__func__all__true" ],
    [ "and", "group__arith__func__and.htm", "group__arith__func__and" ],
    [ "anytrue", "group__reduce__func__any__true.htm", "group__reduce__func__any__true" ],
    [ "approx1", "group__signal__func__approx1.htm", "group__signal__func__approx1" ],
    [ "approx2", "group__signal__func__approx2.htm", "group__signal__func__approx2" ],
    [ "arg", "group__arith__func__arg.htm", "group__arith__func__arg" ],
    [ "array::device<T>", "group__device__func__device.htm", "group__device__func__device" ],
    [ "asin", "group__arith__func__asin.htm", "group__arith__func__asin" ],
    [ "asinh", "group__arith__func__asinh.htm", "group__arith__func__asinh" ],
    [ "assign", "group__index__func__assign.htm", "group__index__func__assign" ],
    [ "atan/atan2", "group__arith__func__atan.htm", "group__arith__func__atan" ],
    [ "atanh", "group__arith__func__atanh.htm", "group__arith__func__atanh" ],
    [ "bilateral", "group__image__func__bilateral.htm", "group__image__func__bilateral" ],
    [ "bitand", "group__arith__func__bitand.htm", "group__arith__func__bitand" ],
    [ "bitor", "group__arith__func__bitor.htm", "group__arith__func__bitor" ],
    [ "bitshiftl", "group__arith__func__shiftl.htm", "group__arith__func__shiftl" ],
    [ "bitshiftr", "group__arith__func__shiftr.htm", "group__arith__func__shiftr" ],
    [ "bitxor", "group__arith__func__bitxor.htm", "group__arith__func__bitxor" ],
    [ "cast", "group__arith__func__cast.htm", "group__arith__func__cast" ],
    [ "cbrt", "group__arith__func__cbrt.htm", "group__arith__func__cbrt" ],
    [ "ceil", "group__arith__func__ceil.htm", "group__arith__func__ceil" ],
    [ "cholesky", "group__lapack__factor__func__cholesky.htm", "group__lapack__factor__func__cholesky" ],
    [ "col/cols", "group__array__mem__col.htm", "group__array__mem__col" ],
    [ "colorspace", "group__image__func__colorspace.htm", "group__image__func__colorspace" ],
    [ "complex", "group__arith__func__cplx.htm", "group__arith__func__cplx" ],
    [ "conjg", "group__arith__func__conjg.htm", "group__arith__func__conjg" ],
    [ "constant", "group__data__func__constant.htm", "group__data__func__constant" ],
    [ "convolve", "group__signal__func__convolve.htm", "group__signal__func__convolve" ],
    [ "convolve1", "group__signal__func__convolve1.htm", "group__signal__func__convolve1" ],
    [ "convolve2", "group__signal__func__convolve2.htm", "group__signal__func__convolve2" ],
    [ "convolve3", "group__signal__func__convolve3.htm", "group__signal__func__convolve3" ],
    [ "corrcoef", "group__stat__func__corrcoef.htm", "group__stat__func__corrcoef" ],
    [ "cos", "group__arith__func__cos.htm", "group__arith__func__cos" ],
    [ "cosh", "group__arith__func__cosh.htm", "group__arith__func__cosh" ],
    [ "count", "group__reduce__func__count.htm", "group__reduce__func__count" ],
    [ "cov", "group__stat__func__cov.htm", "group__stat__func__cov" ],
    [ "deleteImageMem", "group__imagemem__func__delete.htm", "group__imagemem__func__delete" ],
    [ "dense", "group__sparse__func__dense.htm", "group__sparse__func__dense" ],
    [ "det", "group__lapack__ops__func__det.htm", "group__lapack__ops__func__det" ],
    [ "deviceInfo", "group__device__func__prop.htm", "group__device__func__prop" ],
    [ "deviceMemInfo", "group__device__func__mem.htm", "group__device__func__mem" ],
    [ "diag", "group__data__func__diag.htm", "group__data__func__diag" ],
    [ "diff1", "group__calc__func__diff1.htm", "group__calc__func__diff1" ],
    [ "diff2", "group__calc__func__diff2.htm", "group__calc__func__diff2" ],
    [ "dilate", "group__image__func__dilate.htm", "group__image__func__dilate" ],
    [ "dilate3d", "group__image__func__dilate3d.htm", "group__image__func__dilate3d" ],
    [ "div", "group__arith__func__div.htm", "group__arith__func__div" ],
    [ "dot", "group__blas__func__dot.htm", "group__blas__func__dot" ],
    [ "eq", "group__arith__func__eq.htm", "group__arith__func__eq" ],
    [ "erf", "group__arith__func__erf.htm", "group__arith__func__erf" ],
    [ "erfc", "group__arith__func__erfc.htm", "group__arith__func__erfc" ],
    [ "erode", "group__image__func__erode.htm", "group__image__func__erode" ],
    [ "erode3d", "group__image__func__erode3d.htm", "group__image__func__erode3d" ],
    [ "exp", "group__arith__func__exp.htm", "group__arith__func__exp" ],
    [ "expm1", "group__arith__func__expm1.htm", "group__arith__func__expm1" ],
    [ "factorial", "group__arith__func__factorial.htm", "group__arith__func__factorial" ],
    [ "fast", "group__cv__func__fast.htm", "group__cv__func__fast" ],
    [ "fft", "group__signal__func__fft.htm", "group__signal__func__fft" ],
    [ "fft2", "group__signal__func__fft2.htm", "group__signal__func__fft2" ],
    [ "fft3", "group__signal__func__fft3.htm", "group__signal__func__fft3" ],
    [ "fftC2R", "group__signal__func__fft__c2r.htm", "group__signal__func__fft__c2r" ],
    [ "fftConvolve", "group__signal__func__fft__convolve.htm", "group__signal__func__fft__convolve" ],
    [ "fftConvolve2", "group__signal__func__fft__convolve2.htm", "group__signal__func__fft__convolve2" ],
    [ "fftConvolve3", "group__signal__func__fft__convolve3.htm", "group__signal__func__fft__convolve3" ],
    [ "fftR2C", "group__signal__func__fft__r2c.htm", "group__signal__func__fft__r2c" ],
    [ "fir", "group__signal__func__fir.htm", "group__signal__func__fir" ],
    [ "flat", "group__manip__func__flat.htm", "group__manip__func__flat" ],
    [ "flip", "group__manip__func__flip.htm", "group__manip__func__flip" ],
    [ "floor", "group__arith__func__floor.htm", "group__arith__func__floor" ],
    [ "free", "group__device__func__free.htm", "group__device__func__free" ],
    [ "freeHost", "group__device__func__free__host.htm", "group__device__func__free__host" ],
    [ "freePinned", "group__device__func__free__pinned.htm", "group__device__func__free__pinned" ],
    [ "gaussiankernel", "group__image__func__gauss.htm", "group__image__func__gauss" ],
    [ "ge", "group__arith__func__ge.htm", "group__arith__func__ge" ],
    [ "getActiveBackend", "group__unified__func__getactivebackend.htm", "group__unified__func__getactivebackend" ],
    [ "getAvailableBackends", "group__unified__func__getavailbackends.htm", "group__unified__func__getavailbackends" ],
    [ "getBackendCount", "group__unified__func__getbackendcount.htm", "group__unified__func__getbackendcount" ],
    [ "getBackendId", "group__unified__func__getbackendid.htm", "group__unified__func__getbackendid" ],
    [ "getDefaultRandomEngine", "group__random__func__get__default__engine.htm", "group__random__func__get__default__engine" ],
    [ "getDevice", "group__device__func__get.htm", "group__device__func__get" ],
    [ "getDeviceCount", "group__device__func__count.htm", "group__device__func__count" ],
    [ "getDeviceId", "group__unified__func__getdeviceid.htm", "group__unified__func__getdeviceid" ],
    [ "getSeed", "group__random__func__get__seed.htm", "group__random__func__get__seed" ],
    [ "gloh", "group__cv__func__gloh.htm", null ],
    [ "grad", "group__calc__func__grad.htm", "group__calc__func__grad" ],
    [ "gray2rgb", "group__image__func__gray2rgb.htm", "group__image__func__gray2rgb" ],
    [ "gt", "group__arith__func__gt.htm", "group__arith__func__gt" ],
    [ "hammingMatcher", "group__cv__func__hamming__matcher.htm", "group__cv__func__hamming__matcher" ],
    [ "harris", "group__cv__func__harris.htm", "group__cv__func__harris" ],
    [ "histequal", "group__image__func__histequal.htm", "group__image__func__histequal" ],
    [ "histogram", "group__image__func__histogram.htm", "group__image__func__histogram" ],
    [ "homography", "group__cv__func__homography.htm", "group__cv__func__homography" ],
    [ "hsv2rgb", "group__image__func__hsv2rgb.htm", "group__image__func__hsv2rgb" ],
    [ "hypot", "group__arith__func__hypot.htm", "group__arith__func__hypot" ],
    [ "identity", "group__data__func__identity.htm", "group__data__func__identity" ],
    [ "ifft", "group__signal__func__ifft.htm", "group__signal__func__ifft" ],
    [ "ifft2", "group__signal__func__ifft2.htm", "group__signal__func__ifft2" ],
    [ "ifft3", "group__signal__func__ifft3.htm", "group__signal__func__ifft3" ],
    [ "iir", "group__signal__func__iir.htm", "group__signal__func__iir" ],
    [ "imag", "group__arith__func__imag.htm", "group__arith__func__imag" ],
    [ "index", "group__index__func__index.htm", "group__index__func__index" ],
    [ "info", "group__device__func__info.htm", "group__device__func__info" ],
    [ "infoString", "group__device__func__info__string.htm", "group__device__func__info__string" ],
    [ "inverse", "group__lapack__ops__func__inv.htm", "group__lapack__ops__func__inv" ],
    [ "iota", "group__data__func__iota.htm", "group__data__func__iota" ],
    [ "isDoubleAvailable", "group__device__func__dbl.htm", "group__device__func__dbl" ],
    [ "isImageIoAvailable", "group__imageio__func__available.htm", "group__imageio__func__available" ],
    [ "isLAPACKAvailable", "group__lapack__helper__func__available.htm", null ],
    [ "isNan", "group__arith__func__isnan.htm", "group__arith__func__isnan" ],
    [ "isinf", "group__arith__func__isinf.htm", "group__arith__func__isinf" ],
    [ "iszero", "group__arith__func__iszero.htm", "group__arith__func__iszero" ],
    [ "join", "group__manip__func__join.htm", "group__manip__func__join" ],
    [ "le", "group__arith__func__le.htm", "group__arith__func__le" ],
    [ "lgamma", "group__arith__func__lgamma.htm", "group__arith__func__lgamma" ],
    [ "loadImage", "group__imageio__func__load.htm", "group__imageio__func__load" ],
    [ "loadImageMem", "group__imagemem__func__load.htm", "group__imagemem__func__load" ],
    [ "log", "group__arith__func__log.htm", "group__arith__func__log" ],
    [ "log10", "group__arith__func__log10.htm", "group__arith__func__log10" ],
    [ "log1p", "group__arith__func__log1p.htm", "group__arith__func__log1p" ],
    [ "lower", "group__data__func__lower.htm", "group__data__func__lower" ],
    [ "lt", "group__arith__func__lt.htm", "group__arith__func__lt" ],
    [ "lu", "group__lapack__factor__func__lu.htm", "group__lapack__factor__func__lu" ],
    [ "matchTemplate", "group__cv__func__match__template.htm", "group__cv__func__match__template" ],
    [ "matmul", "group__blas__func__matmul.htm", "group__blas__func__matmul" ],
    [ "max", "group__reduce__func__max.htm", "group__reduce__func__max" ],
    [ "max", "group__arith__func__max.htm", "group__arith__func__max" ],
    [ "maxfilt", "group__image__func__maxfilt.htm", "group__image__func__maxfilt" ],
    [ "mean", "group__stat__func__mean.htm", "group__stat__func__mean" ],
    [ "meanshift", "group__image__func__mean__shift.htm", "group__image__func__mean__shift" ],
    [ "medfilt", "group__image__func__medfilt.htm", "group__image__func__medfilt" ],
    [ "median", "group__stat__func__median.htm", "group__stat__func__median" ],
    [ "min", "group__arith__func__min.htm", "group__arith__func__min" ],
    [ "min", "group__reduce__func__min.htm", "group__reduce__func__min" ],
    [ "minfilt", "group__image__func__minfilt.htm", "group__image__func__minfilt" ],
    [ "mod", "group__arith__func__mod.htm", "group__arith__func__mod" ],
    [ "moddims", "group__manip__func__moddims.htm", "group__manip__func__moddims" ],
    [ "moments", "group__image__func__moments.htm", "group__image__func__moments" ],
    [ "mul", "group__arith__func__mul.htm", "group__arith__func__mul" ],
    [ "nearestNeighbour", "group__cv__func__nearest__neighbour.htm", "group__cv__func__nearest__neighbour" ],
    [ "neg", "group__arith__func__neg.htm", "group__arith__func__neg" ],
    [ "neq", "group__arith__func__neq.htm", "group__arith__func__neq" ],
    [ "norm", "group__lapack__ops__func__norm.htm", "group__lapack__ops__func__norm" ],
    [ "not", "group__arith__func__not.htm", "group__arith__func__not" ],
    [ "operator()", "group__array__mem__operator__paren.htm", "group__array__mem__operator__paren" ],
    [ "operator(star)=", "group__array__mem__operator__multiply__eq.htm", "group__array__mem__operator__multiply__eq" ],
    [ "operator+=", "group__array__mem__operator__plus__eq.htm", "group__array__mem__operator__plus__eq" ],
    [ "operator-=", "group__array__mem__operator__minus__eq.htm", "group__array__mem__operator__minus__eq" ],
    [ "operator/=", "group__array__mem__operator__divide__eq.htm", "group__array__mem__operator__divide__eq" ],
    [ "operator=", "group__array__mem__operator__eq.htm", "group__array__mem__operator__eq" ],
    [ "or", "group__arith__func__or.htm", "group__arith__func__or" ],
    [ "orb", "group__cv__func__orb.htm", "group__cv__func__orb" ],
    [ "pinned", "group__device__func__pinned.htm", "group__device__func__pinned" ],
    [ "pow", "group__arith__func__pow.htm", "group__arith__func__pow" ],
    [ "print", "group__print__func__print.htm", "group__print__func__print" ],
    [ "product", "group__reduce__func__product.htm", "group__reduce__func__product" ],
    [ "qr", "group__lapack__factor__func__qr.htm", "group__lapack__factor__func__qr" ],
    [ "randn", "group__random__func__randn.htm", "group__random__func__randn" ],
    [ "randomEngine", "group__random__engine__class.htm", "group__random__engine__class" ],
    [ "randomEngine Constructors", "group__random__engine__func__constructor.htm", "group__random__engine__func__constructor" ],
    [ "randu", "group__random__func__randu.htm", "group__random__func__randu" ],
    [ "range", "group__data__func__range.htm", "group__data__func__range" ],
    [ "rank", "group__lapack__ops__func__rank.htm", "group__lapack__ops__func__rank" ],
    [ "readArray", "group__stream__func__read.htm", "group__stream__func__read" ],
    [ "real", "group__arith__func__real.htm", "group__arith__func__real" ],
    [ "regions", "group__image__func__regions.htm", "group__image__func__regions" ],
    [ "rem", "group__arith__func__rem.htm", "group__arith__func__rem" ],
    [ "reorder", "group__manip__func__reorder.htm", "group__manip__func__reorder" ],
    [ "replace", "group__data__func__replace.htm", "group__data__func__replace" ],
    [ "resize", "group__transform__func__resize.htm", "group__transform__func__resize" ],
    [ "rgb2gray", "group__image__func__rgb2gray.htm", "group__image__func__rgb2gray" ],
    [ "rgb2hsv", "group__image__func__rgb2hsv.htm", "group__image__func__rgb2hsv" ],
    [ "rgb2ycbcr", "group__image__func__rgb2ycbcr.htm", "group__image__func__rgb2ycbcr" ],
    [ "root", "group__arith__func__root.htm", "group__arith__func__root" ],
    [ "rotate", "group__transform__func__rotate.htm", "group__transform__func__rotate" ],
    [ "round", "group__arith__func__round.htm", "group__arith__func__round" ],
    [ "row/rows", "group__array__mem__row.htm", "group__array__mem__row" ],
    [ "saveArray", "group__stream__func__save.htm", "group__stream__func__save" ],
    [ "saveImage", "group__imageio__func__save.htm", "group__imageio__func__save" ],
    [ "saveImageMem", "group__imagemem__func__save.htm", "group__imagemem__func__save" ],
    [ "scale", "group__transform__func__scale.htm", "group__transform__func__scale" ],
    [ "scan", "group__scan__func__scan.htm", "group__scan__func__scan" ],
    [ "scanByKey", "group__scan__func__scanbykey.htm", "group__scan__func__scanbykey" ],
    [ "select", "group__data__func__select.htm", "group__data__func__select" ],
    [ "setBackend", "group__unified__func__setbackend.htm", "group__unified__func__setbackend" ],
    [ "setDefaultRandomEngineType", "group__random__func__set__type.htm", "group__random__func__set__type" ],
    [ "setDevice", "group__device__func__set.htm", "group__device__func__set" ],
    [ "setSeed", "group__random__func__set__seed.htm", "group__random__func__set__seed" ],
    [ "setintersect", "group__set__func__intersect.htm", "group__set__func__intersect" ],
    [ "setunion", "group__set__func__union.htm", "group__set__func__union" ],
    [ "setunique", "group__set__func__unique.htm", "group__set__func__unique" ],
    [ "shift", "group__manip__func__shift.htm", "group__manip__func__shift" ],
    [ "sift", "group__cv__func__sift.htm", "group__cv__func__sift" ],
    [ "sign", "group__arith__func__sign.htm", "group__arith__func__sign" ],
    [ "sin", "group__arith__func__sin.htm", "group__arith__func__sin" ],
    [ "sinh", "group__arith__func__sinh.htm", "group__arith__func__sinh" ],
    [ "skew", "group__transform__func__skew.htm", "group__transform__func__skew" ],
    [ "slice/slices", "group__array__mem__slice.htm", "group__array__mem__slice" ],
    [ "sobel", "group__image__func__sobel.htm", "group__image__func__sobel" ],
    [ "solve", "group__lapack__solve__func__gen.htm", "group__lapack__solve__func__gen" ],
    [ "solveLU", "group__lapack__solve__lu__func__gen.htm", "group__lapack__solve__lu__func__gen" ],
    [ "sort", "group__sort__func__sort.htm", "group__sort__func__sort" ],
    [ "sortByKey", "group__sort__func__sort__keys.htm", "group__sort__func__sort__keys" ],
    [ "sortIndex", "group__sort__func__sort__index.htm", "group__sort__func__sort__index" ],
    [ "sparse", "group__sparse__func__create.htm", "group__sparse__func__create" ],
    [ "sparseConvertTo", "group__sparse__func__convert__to.htm", "group__sparse__func__convert__to" ],
    [ "sparseGetColdx", "group__sparse__func__col__idx.htm", "group__sparse__func__col__idx" ],
    [ "sparseGetInfo", "group__sparse__func__info.htm", "group__sparse__func__info" ],
    [ "sparseGetNNZ", "group__sparse__func__nnz.htm", "group__sparse__func__nnz" ],
    [ "sparseGetRowIdx", "group__sparse__func__row__idx.htm", "group__sparse__func__row__idx" ],
    [ "sparseGetStorage", "group__sparse__func__storage.htm", "group__sparse__func__storage" ],
    [ "sparseGetValues", "group__sparse__func__values.htm", "group__sparse__func__values" ],
    [ "sqrt", "group__arith__func__sqrt.htm", "group__arith__func__sqrt" ],
    [ "stdev", "group__stat__func__stdev.htm", "group__stat__func__stdev" ],
    [ "sub", "group__arith__func__sub.htm", "group__arith__func__sub" ],
    [ "sum", "group__reduce__func__sum.htm", "group__reduce__func__sum" ],
    [ "susan", "group__cv__func__susan.htm", "group__cv__func__susan" ],
    [ "svd", "group__lapack__factor__func__svd.htm", "group__lapack__factor__func__svd" ],
    [ "sync", "group__device__func__sync.htm", "group__device__func__sync" ],
    [ "tan/tan2", "group__arith__func__tan.htm", "group__arith__func__tan" ],
    [ "tanh", "group__arith__func__tanh.htm", "group__arith__func__tanh" ],
    [ "tgamma", "group__arith__func__tgamma.htm", "group__arith__func__tgamma" ],
    [ "tile", "group__manip__func__tile.htm", "group__manip__func__tile" ],
    [ "toString", "group__print__func__tostring.htm", "group__print__func__tostring" ],
    [ "transform", "group__transform__func__transform.htm", "group__transform__func__transform" ],
    [ "transformcoordinates", "group__transform__func__coordinates.htm", "group__transform__func__coordinates" ],
    [ "translate", "group__transform__func__translate.htm", "group__transform__func__translate" ],
    [ "transpose", "group__blas__func__transpose.htm", "group__blas__func__transpose" ],
    [ "trunc", "group__arith__func__trunc.htm", "group__arith__func__trunc" ],
    [ "unwrap", "group__image__func__unwrap.htm", "group__image__func__unwrap" ],
    [ "upper", "group__data__func__upper.htm", "group__data__func__upper" ],
    [ "util", "group__index__func__util.htm", null ],
    [ "var", "group__stat__func__var.htm", "group__stat__func__var" ],
    [ "where", "group__scan__func__where.htm", "group__scan__func__where" ],
    [ "wrap", "group__image__func__wrap.htm", "group__image__func__wrap" ],
    [ "ycbcr2rgb", "group__image__func__ycbcr2rgb.htm", "group__image__func__ycbcr2rgb" ]
];